@@ -7,12 +7,14 @@ from notion_oauth_handler.core.oauth_handler import NotionOAuthHandler
 
 
 OAUTH_HANDLER_REQUEST_KEY = '__ouath_handler__'
+CUSTOM_SETTINGS_REQUEST_KEY = '__custom_settings__'
 
 
 def notion_oauth_middleware_factory(
         notion_client_id: str,
         notion_client_secret: str,
         consumer: NotionOAuthConsumer,
+        custom_settings: dict,
 ):
     oauth_handler = NotionOAuthHandler(
         consumer=consumer,
@@ -22,6 +24,7 @@ def notion_oauth_middleware_factory(
     @middleware
     async def middleware_impl(request: Request, handler: Callable[[Request], Awaitable[Response]]) -> Response:
         request[OAUTH_HANDLER_REQUEST_KEY] = oauth_handler
+        request[CUSTOM_SETTINGS_REQUEST_KEY] = custom_settings
         return await handler(request)
 
     return middleware_impl
